@@ -7,9 +7,9 @@ from PySide6.QtWidgets import  QApplication, QFileDialog, QMainWindow
 
 from scipy import optimize as optim
 import re
-from export import export_fit
-from loadgui import loadUiWidget
-from options import Options_
+from pyCftool.export import export_fit
+from pyCftool.loadgui import loadUiWidget
+from pyCftool.options import Options_
 
 class function():
     def __init__(self, eq):
